function [EROC Fan_Diameter Fuel_Cost Maintenance_Cost Max_Range TOFL TSFC Engine_Weight]=turbofan_rses4rave(inputs,prefs,targets)
%This is an example function to demonstrate the use of user-supplied
%functions in Rave. 
%
%Things to note: The function takes 3 inputs. These will be supplied by
%Rave. Every function you use in Rave must take these three inputs,
%regardless of whether the function actually uses them.
%
%The first input is your entire data table. Consequently, the first thing
%you'll want to actually do in your function is extract whichever columns
%(variables) you want to use from the data set.
%
%The second input is the "preference" for each variable that comprises the
%data set. Most of your functions won't use this, but it can be useful for
%certain types of decision making problems to create weighted sums of
%variables.
%
%The third input is the "target" value for each variable in your data set.
%Again, you usually won't use this, but if you ever need to create a
%function that knows what the "best" value for each variable is, it'll be
%there if you need it.
%
%OUTPUTS: Notice that unlike the inputs to the function, which are all
%grouped into one matrix called "inputs", you must list each output as a
%separate variable. This way Rave knows what variables in your function you
%want to become variables in Rave. Consequently, variables created by
%matlab functions can't have spaces in their names (though variables you
%load from text functions can) and must be valid MATLAB variable names.
%
%If you want to use functions you've written to be used elsewhere in Rave
%you'll have to "wrap" them with an interface function that follows the
%format explained above. Maybe later i'll (or someone else) will think of a
%clever way to automate the wrapping. 
%
%Aside from meeting the requirements of the first line of the function, you
%can pretty much do whatever you want inside the function. There is one
%more IMPORTANT detail though. Your functions must be "vectorized," meaning
%the must be capable of calculating multiple data points in a single
%function call. For example, if Rave needs to calculate 10 data points with
%your function, it will only call your function once and ask for the values
%at all 10 points; it will NOT call your function 10 separate times asking 
%for one point each time. If Rave needs to calculate n data points, the
%"inputs" matrix to this function will contains n rows, one row for each
%point to be calculated. Thus, if your code is only capable of calculating
%one data point at a time, you'll need to wrap it in a for loop like
%"for n=1:size(inputs,1)" to calculate results for each row. 
%(Note, this system is used by Rave because there are usually MUCH more
%efficient ways for you to vectorize your functions than with a for loop,
%whereas if Rave did the vectorizing for you, it would pretty much have to
%use a for loop. As an example, all of the functions contained below are 
%vectorized without using any loops.)


%Ok, on to the functions:

%Extract columns from the data set that we'll be using in this function. To
%do this you have to know which column's they're in. I haven't come up with
%a good way to make this less onerous yet...

FPR=inputs(:,6);
HPTStages=inputs(:,12);
LPCPR=inputs(:,7);
Loading=inputs(:,11);
OPR=inputs(:,8);
Payload=inputs(:,3);
Range1=inputs(:,4);
Range2=inputs(:,5);
T4max=inputs(:,9);
Thrust=inputs(:,2);
Vratio=inputs(:,10);

%Once that's done, you can pretty much do whatever you'd like. The
%functions included here are a combination of artificial neural networks
%and polynomial response surface equations. 

nruns=size(inputs,1);


%Calculate EROC (Engine Related Operating Cost)
logsig=@(n) 1./(1 + exp(-n));
EROC=zeros(nruns,1);
isif=HPTStages==1;
eroc11=(605.531511183002+1528.45535374685.*logsig(2.2055139702098-0.0000414836364.*Thrust+1.662475526236.*FPR-0.2057216098898.*LPCPR-0.0108448445253.*OPR-0.0010446123266.*T4max+0.7034294543612.*Vratio-0.4494625748367.*Loading+0.0000006986404.*Payload+0.0006813746014.*Range1)+1733.04271815407.*logsig(3.3673312720209+0.0000338511446.*Thrust-1.8653157499607.*FPR-0.5362235155792.*LPCPR-0.0006881615039.*OPR-0.0002774612087.*T4max-0.079642476941.*Vratio+0.573973047163.*Loading+0.0000002347038.*Payload+0.0007610969162.*Range1)-557.953084674847.*logsig(3.1377824955772+0.0000728005434.*Thrust-0.8327281609806.*FPR+0.0090703265779.*LPCPR-0.0692587723449.*OPR-0.0010666897486.*T4max+1.7144584245592.*Vratio-4.5838619926828.*Loading+0.0000110100621.*Payload+0.0003409284397.*Range1)-599.647693572492.*logsig(5.6063399809033+0.0000399720182.*Thrust+9.3893845186122.*FPR-1.7563810451346.*LPCPR+0.0068276127615.*OPR-0.0041144617949.*T4max-2.033801094279.*Vratio+0.6463504135058.*Loading+0.0000012088982.*Payload+0.0001562257509.*Range1)-1393.13324640662.*logsig(0.3062273154359-0.0000466857713.*Thrust+0.6916797739756.*FPR-0.4461256049473.*LPCPR-0.011441768171.*OPR-0.0002875148714.*T4max+2.5610897579786.*Vratio-0.5622274598449.*Loading-0.0000003636104.*Payload-0.0005752654953.*Range1)+534.692846199952.*logsig(2.5891591143225+0.0001212201262.*Thrust-0.9149586139077.*FPR-0.3450622853607.*LPCPR-0.0640935566585.*OPR-0.0023806520706.*T4max+3.4660622718933.*Vratio+0.104314597837.*Loading+0.0000081617831.*Payload+0.0001057093271.*Range1)+904.70099283653.*logsig(5.3353038353928+0.0001158891289.*Thrust-7.0490178233963.*FPR-1.4652230069694.*LPCPR+0.0095941044022.*OPR-0.0015641967136.*T4max+2.9247937646404.*Vratio+4.035124389866.*Loading-0.0000015002231.*Payload+0.0010111624334.*Range1)-393.046906655498.*logsig(19.1773194370845-0.0000087362276.*Thrust-14.0410823064069.*FPR-0.7094692620829.*LPCPR-0.0338333301346.*OPR-0.0010016940581.*T4max+4.1329515772571.*Vratio+6.4474758441639.*Loading-0.0000021005765.*Payload+0.0000261333037.*Range1)) ;
eroc12=(2076.11224953676-2159.07256385841.*logsig(1.0562211448435-0.0000522573767.*Thrust+1.7335297921812.*FPR+0.0280748572672.*LPCPR-0.0038365563991.*OPR-0.0000696632028.*T4max+0.1792277984837.*Vratio-0.4368662704288.*Loading+0.0000000435574.*Payload-0.0007085619426.*Range1)-1324.97656097722.*logsig((-3.8662205470713)-0.0000120225865.*Thrust+4.1793024076498.*FPR+0.0610300487335.*LPCPR-0.0142905850044.*OPR-0.0011118465869.*T4max+0.4715992242778.*Vratio+1.1232103635149.*Loading-0.0000001068523.*Payload-0.0000942170031.*Range1)-754.261878843006.*logsig(1.5360409389939-0.0001207547793.*Thrust-0.4657762057819.*FPR+1.7676977243025.*LPCPR-0.0721544114249.*OPR+0.0032065742719.*T4max-0.3675428799838.*Vratio-8.2484382411461.*Loading+0.0000032436394.*Payload-0.0006369644107.*Range1)+2259.30256074489.*logsig(0.265610361623-0.00002465043.*Thrust+0.2199629513661.*FPR+0.002636145817.*LPCPR-0.0070768761857.*OPR-0.0001921598913.*T4max+0.636510299879.*Vratio-0.116827194463.*Loading-0.0000000104664.*Payload+0.0007296629782.*Range1)+759.531012015289.*logsig(5.5554203411892+0.0001188027265.*Thrust+12.8664225640823.*FPR-3.4504150940441.*LPCPR-0.0160544365615.*OPR-0.0057059392755.*T4max-0.2441271995964.*Vratio-2.4812127342036.*Loading+0.0000023713702.*Payload-0.0002205488671.*Range1)-536.911401549202.*logsig(6.5737277985753+0.0000841544419.*Thrust-11.4966766916323.*FPR-0.8141565773735.*LPCPR-0.0077069996871.*OPR+0.0000255644367.*T4max+5.584571811001.*Vratio+1.191355133772.*Loading+0.0000032052506.*Payload+0.0004400091943.*Range1)-438.449062925706.*logsig(8.1953937289189-0.0001174358715.*Thrust+1.6658794177885.*FPR+0.6398550940955.*LPCPR-0.0046614405259.*OPR+0.000628845703.*T4max-4.5783302182005.*Vratio-5.3929342326519.*Loading-0.0000017301947.*Payload-0.0002680990805.*Range1)+618.895718140422.*logsig((-3.744898041836)-0.0001267001453.*Thrust-16.4708789015451.*FPR+4.3363868792419.*LPCPR+0.0032113593418.*OPR+0.0060737453576.*T4max+0.7084088016562.*Vratio+2.9463214155087.*Loading-0.0000009442037.*Payload+0.0000961658243.*Range1)) ;
EROC(isif)=eroc11(isif);
EROC(~isif)=eroc12(~isif);

%Calculate Fan Diameter
Fan_Diameter=(-345.623759)+Thrust.*0.00268754981+FPR.*238.74683+LPCPR.*-20.0630922+OPR.*1.43235817+T4max.*-0.119391122+Vratio.*445.48179+Thrust.*Thrust.*-0.0000000115831436+FPR.*Thrust.*-0.000625024112+FPR.*FPR.*-23.8840247+LPCPR.*Thrust.*0.0000573305379+LPCPR.*FPR.*9.7071519+LPCPR.*LPCPR.*-3.03994775+OPR.*Thrust.*-0.000000217525853+OPR.*FPR.*-0.722922406+OPR.*LPCPR.*0.0198829065+OPR.*OPR.*0.000161976738+T4max.*Thrust.*-0.0000000115486723+T4max.*FPR.*0.0444759209+T4max.*LPCPR.*-0.00186559461+T4max.*OPR.*0.000218932269+T4max.*T4max.*-0.00000639466588+Vratio.*Thrust.*0.0000811544961+Vratio.*FPR.*-181.468996+Vratio.*LPCPR.*12.8907807+Vratio.*OPR.*-0.618134437+Vratio.*T4max.*0.0513410443+Vratio.*Vratio.*-96.9944003;

%Calculate mission fuel cost
Fuel_Cost=zeros(nruns,1);
isif=HPTStages==1;
fuelcost1=((-10945.9758495397)+20239.9959831044.*logsig((-1.1088931052768)+0.0000135627885.*Thrust+0.5883721169187.*FPR-0.0406994004303.*LPCPR-0.0015117887882.*OPR-0.0001241247158.*T4max-0.0015934818334.*Vratio+0.0825968665769.*Loading+0.000010019186.*Payload+0.0009179159531.*Range1)+21125.8357876375.*logsig((-3.1345666585023)+0.0000124450484.*Thrust+0.5945655078273.*FPR+0.0212812865533.*LPCPR-0.0039146113894.*OPR-0.0003309053771.*T4max+0.3300705646061.*Vratio-0.0494243922912.*Loading+0.0000081458369.*Payload+0.0009983022436.*Range1)+4709.03280969801.*logsig(5.6337171941726+0.0001340173962.*Thrust-3.5332212271028.*FPR-0.0802170034445.*LPCPR+0.0248845854564.*OPR-0.0022604114078.*T4max-1.2421082955077.*Vratio+1.6275089133626.*Loading-0.0000048512364.*Payload+0.001110411079.*Range1)+21070.7056342678.*logsig(1.901793282882-0.0000124059342.*Thrust-0.6520652354453.*FPR+0.0394655056993.*LPCPR+0.0038548959183.*OPR+0.0002387385557.*T4max-0.0743140547393.*Vratio-0.0957981613689.*Loading-0.00001643196.*Payload+0.0008259931059.*Range1)+7949.14251223124.*logsig((-100.732251549355)+0.0000059382517.*Thrust+45.5816727359237.*FPR-0.0764893846195.*LPCPR+0.1283803056654.*OPR-0.0112306641704.*T4max+29.4371938260465.*Vratio-2.0127095845003.*Loading+0.0000145343122.*Payload+0.0008597681086.*Range1)+10014.3701035509.*logsig((-6.6783685772265)+0.000018872187.*Thrust+0.7613046630713.*FPR+0.0841669242322.*LPCPR-0.0820141237408.*OPR+0.0010322792586.*T4max-0.2175770745959.*Vratio-0.1553487264993.*Loading+0.0000196358918.*Payload+0.0009341034941.*Range1)-14503.595264991.*logsig(6.0166875190365+0.0000013223456.*Thrust-0.5851015897124.*FPR+0.0137226661453.*LPCPR-0.012265799397.*OPR+0.0005532829282.*T4max-0.4251660361767.*Vratio-0.1914116543128.*Loading-0.0000515421624.*Payload-0.0010912509576.*Range1)) .*(0.1482.*0.86);
fuelcost2=(16501.3650942898-51807.097337396.*logsig(1.5381406835111-0.0000086541319.*Thrust-0.4045464764651.*FPR+0.0024888438287.*LPCPR+0.0020342806538.*OPR+0.0001688041653.*T4max-0.137487498772.*Vratio-0.0085534936005.*Loading-0.0000066560568.*Payload-0.0005888732961.*Range1)+10201.167825649.*logsig((-6.5196752229783)+0.0000195544663.*Thrust+0.7444045798246.*FPR+0.1170788622793.*LPCPR-0.0842280361886.*OPR+0.0009097282938.*T4max-0.0960539549945.*Vratio-0.1524702947484.*Loading+0.0000191402816.*Payload+0.0009403934381.*Range1)+34039.3135226647.*logsig(2.001558437318-0.0000095579389.*Thrust-0.5221824215033.*FPR+0.0025509543693.*LPCPR+0.0041116231147.*OPR+0.0002811424044.*T4max-0.2178706592669.*Vratio-0.0183196356334.*Loading-0.000012450833.*Payload+0.0006350292335.*Range1)-4938.79405264175.*logsig((-5.9657795248525)-0.0001275262651.*Thrust+3.5299678143273.*FPR+0.0830985226382.*LPCPR-0.0260133951642.*OPR+0.0024816564119.*T4max+0.9404101050505.*Vratio-0.8367596539297.*Loading+0.0000028847317.*Payload-0.0010762823205.*Range1)+9097.96366771158.*logsig((-97.4007390168941)+0.0000059501889.*Thrust+44.214803727087.*FPR-0.0919546891218.*LPCPR+0.1241442244243.*OPR-0.0109282069118.*T4max+28.3722441682075.*Vratio-0.9893681263976.*Loading+0.000014652333.*Payload+0.0008280874041.*Range1)+9926.67912235926.*logsig((-6.4850247673057)-0.0000053585964.*Thrust+0.6200090622324.*FPR+0.0188685876641.*LPCPR+0.0130176983795.*OPR-0.0007179740847.*T4max+0.7035512180339.*Vratio+0.131348015662.*Loading+0.0000610977949.*Payload+0.0012350095695.*Range1)) .*(0.1482.*0.86);
Fuel_Cost(isif)=fuelcost1(isif);
Fuel_Cost(~isif)=fuelcost2(~isif);

%Calculate mission maintenance cost
Maintenance_Cost=zeros(nruns,1);
isif=HPTStages==1;
maint1=(605.531511183002+1528.45535374685.*logsig(2.2055139702098-0.0000414836364.*Thrust+1.662475526236.*FPR-0.2057216098898.*LPCPR-0.0108448445253.*OPR-0.0010446123266.*T4max+0.7034294543612.*Vratio-0.4494625748367.*Loading+0.0000006986404.*Payload+0.0006813746014.*Range1)+1733.04271815407.*logsig(3.3673312720209+0.0000338511446.*Thrust-1.8653157499607.*FPR-0.5362235155792.*LPCPR-0.0006881615039.*OPR-0.0002774612087.*T4max-0.079642476941.*Vratio+0.573973047163.*Loading+0.0000002347038.*Payload+0.0007610969162.*Range1)-557.953084674847.*logsig(3.1377824955772+0.0000728005434.*Thrust-0.8327281609806.*FPR+0.0090703265779.*LPCPR-0.0692587723449.*OPR-0.0010666897486.*T4max+1.7144584245592.*Vratio-4.5838619926828.*Loading+0.0000110100621.*Payload+0.0003409284397.*Range1)-599.647693572492.*logsig(5.6063399809033+0.0000399720182.*Thrust+9.3893845186122.*FPR-1.7563810451346.*LPCPR+0.0068276127615.*OPR-0.0041144617949.*T4max-2.033801094279.*Vratio+0.6463504135058.*Loading+0.0000012088982.*Payload+0.0001562257509.*Range1)-1393.13324640662.*logsig(0.3062273154359-0.0000466857713.*Thrust+0.6916797739756.*FPR-0.4461256049473.*LPCPR-0.011441768171.*OPR-0.0002875148714.*T4max+2.5610897579786.*Vratio-0.5622274598449.*Loading-0.0000003636104.*Payload-0.0005752654953.*Range1)+534.692846199952.*logsig(2.5891591143225+0.0001212201262.*Thrust-0.9149586139077.*FPR-0.3450622853607.*LPCPR-0.0640935566585.*OPR-0.0023806520706.*T4max+3.4660622718933.*Vratio+0.104314597837.*Loading+0.0000081617831.*Payload+0.0001057093271.*Range1)+904.70099283653.*logsig(5.3353038353928+0.0001158891289.*Thrust-7.0490178233963.*FPR-1.4652230069694.*LPCPR+0.0095941044022.*OPR-0.0015641967136.*T4max+2.9247937646404.*Vratio+4.035124389866.*Loading-0.0000015002231.*Payload+0.0010111624334.*Range1)-393.046906655498.*logsig(19.1773194370845-0.0000087362276.*Thrust-14.0410823064069.*FPR-0.7094692620829.*LPCPR-0.0338333301346.*OPR-0.0010016940581.*T4max+4.1329515772571.*Vratio+6.4474758441639.*Loading-0.0000021005765.*Payload+0.0000261333037.*Range1)) ;
maint2=(2076.11224953676-2159.07256385841.*logsig(1.0562211448435-0.0000522573767.*Thrust+1.7335297921812.*FPR+0.0280748572672.*LPCPR-0.0038365563991.*OPR-0.0000696632028.*T4max+0.1792277984837.*Vratio-0.4368662704288.*Loading+0.0000000435574.*Payload-0.0007085619426.*Range1)-1324.97656097722.*logsig((-3.8662205470713)-0.0000120225865.*Thrust+4.1793024076498.*FPR+0.0610300487335.*LPCPR-0.0142905850044.*OPR-0.0011118465869.*T4max+0.4715992242778.*Vratio+1.1232103635149.*Loading-0.0000001068523.*Payload-0.0000942170031.*Range1)-754.261878843006.*logsig(1.5360409389939-0.0001207547793.*Thrust-0.4657762057819.*FPR+1.7676977243025.*LPCPR-0.0721544114249.*OPR+0.0032065742719.*T4max-0.3675428799838.*Vratio-8.2484382411461.*Loading+0.0000032436394.*Payload-0.0006369644107.*Range1)+2259.30256074489.*logsig(0.265610361623-0.00002465043.*Thrust+0.2199629513661.*FPR+0.002636145817.*LPCPR-0.0070768761857.*OPR-0.0001921598913.*T4max+0.636510299879.*Vratio-0.116827194463.*Loading-0.0000000104664.*Payload+0.0007296629782.*Range1)+759.531012015289.*logsig(5.5554203411892+0.0001188027265.*Thrust+12.8664225640823.*FPR-3.4504150940441.*LPCPR-0.0160544365615.*OPR-0.0057059392755.*T4max-0.2441271995964.*Vratio-2.4812127342036.*Loading+0.0000023713702.*Payload-0.0002205488671.*Range1)-536.911401549202.*logsig(6.5737277985753+0.0000841544419.*Thrust-11.4966766916323.*FPR-0.8141565773735.*LPCPR-0.0077069996871.*OPR+0.0000255644367.*T4max+5.584571811001.*Vratio+1.191355133772.*Loading+0.0000032052506.*Payload+0.0004400091943.*Range1)-438.449062925706.*logsig(8.1953937289189-0.0001174358715.*Thrust+1.6658794177885.*FPR+0.6398550940955.*LPCPR-0.0046614405259.*OPR+0.000628845703.*T4max-4.5783302182005.*Vratio-5.3929342326519.*Loading-0.0000017301947.*Payload-0.0002680990805.*Range1)+618.895718140422.*logsig((-3.744898041836)-0.0001267001453.*Thrust-16.4708789015451.*FPR+4.3363868792419.*LPCPR+0.0032113593418.*OPR+0.0060737453576.*T4max+0.7084088016562.*Vratio+2.9463214155087.*Loading-0.0000009442037.*Payload+0.0000961658243.*Range1)) ;
Maintenance_Cost(isif)=maint1(isif);
Maintenance_Cost(~isif)=maint2(~isif);

%Calculate max range of the aircraft
Max_Range=zeros(nruns,1);
isif=HPTStages==1;
range1=((-41108.9518)+Thrust.*-0.143255604+FPR.*29219.052+LPCPR.*-928.222226+OPR.*101.734253+T4max.*-5.8713429+Vratio.*37098.5435+Loading.*1192.48914+Payload.*0.00396632933+Thrust.*Thrust.*-0.000000525276616+FPR.*Thrust.*0.0492668309+FPR.*FPR.*-5532.09874+LPCPR.*Thrust.*0.00173297176+LPCPR.*FPR.*543.124405+LPCPR.*LPCPR.*-270.436017+OPR.*Thrust.*0.0000125175877+OPR.*FPR.*-49.1376478+OPR.*LPCPR.*1.7975965+OPR.*OPR.*-0.339554438+T4max.*Thrust.*-0.000000507327334+T4max.*FPR.*2.9972574+T4max.*LPCPR.*-0.169662214+T4max.*OPR.*0.0275672141+T4max.*T4max.*-0.00077609047+Vratio.*Thrust.*0.0374052548+Vratio.*FPR.*-13017.2935+Vratio.*LPCPR.*953.641033+Vratio.*OPR.*-45.1332968+Vratio.*T4max.*3.46229195+Vratio.*Vratio.*-8248.401+Loading.*Thrust.*-0.0109187469+Loading.*FPR.*-729.881121+Loading.*LPCPR.*446.27644+Loading.*OPR.*-16.409238+Loading.*T4max.*0.233182307+Loading.*Vratio.*-1404.73384+Loading.*Loading.*3504.45524+Payload.*Thrust.*0.00000025178941+Payload.*FPR.*-0.000731200934+Payload.*LPCPR.*-0.000799270162+Payload.*OPR.*-0.0000811333251+Payload.*T4max.*-0.00000276203769+Payload.*Vratio.*-0.00816917478+Payload.*Loading.*-0.00935756273+Payload.*Payload.*-0.0000000481114883) ;
range2=((-41503.9927)+Thrust.*-0.143393296+FPR.*29328.1677+LPCPR.*-954.021703+OPR.*101.959895+T4max.*-5.8738683+Vratio.*37471.3051+Loading.*581.851234+Payload.*0.00381005525+Thrust.*Thrust.*-0.000000530079638+FPR.*Thrust.*0.048723288+FPR.*FPR.*-5553.78032+LPCPR.*Thrust.*0.00192914462+LPCPR.*FPR.*554.073676+LPCPR.*LPCPR.*-273.759575+OPR.*Thrust.*0.0000102489077+OPR.*FPR.*-49.3505471+OPR.*LPCPR.*1.98200232+OPR.*OPR.*-0.342300591+T4max.*Thrust.*-0.0000000291410754+T4max.*FPR.*3.01408841+T4max.*LPCPR.*-0.177488651+T4max.*OPR.*0.0277556365+T4max.*T4max.*-0.00078262366+Vratio.*Thrust.*0.0370437707+Vratio.*FPR.*-13072.0586+Vratio.*LPCPR.*970.706315+Vratio.*OPR.*-45.3328465+Vratio.*T4max.*3.47073055+Vratio.*Vratio.*-8340.36567+Loading.*Thrust.*-0.00550783807+Loading.*FPR.*-364.482106+Loading.*LPCPR.*241.998389+Loading.*OPR.*-9.30572048+Loading.*T4max.*0.124787321+Loading.*Vratio.*-705.912901+Loading.*Loading.*846.673116+Payload.*Thrust.*0.000000249960164+Payload.*FPR.*-0.000662953766+Payload.*LPCPR.*-0.000754866967+Payload.*OPR.*-0.0000815531734+Payload.*T4max.*-0.00000272157417+Payload.*Vratio.*-0.00824906851+Payload.*Loading.*-0.00474497559+Payload.*Payload.*-0.0000000476194117) ;
Max_Range(isif)=range1(isif);
Max_Range(~isif)=range2(~isif);

%Calculate takeoff field length of the aircraft:
TOFL=zeros(nruns,1);
isif=HPTStages==1;
tofl1=(exp(11.6703935+Thrust.*-0.0000326600101+FPR.*-1.41803275+LPCPR.*0.00415193051+OPR.*-0.0029531291+T4max.*-0.000195797154+Vratio.*-1.92648403+Loading.*0.360255868+Payload.*0.0000284530331+Range2.*0.000163181712+Thrust.*Thrust.*0.000000000606111453+FPR.*Thrust.*-0.00000438394509+FPR.*FPR.*0.508561336+LPCPR.*Thrust.*-0.000000658367223+LPCPR.*FPR.*-0.0092802591+LPCPR.*LPCPR.*0.0160130278+OPR.*Thrust.*0.00000000140482047+OPR.*FPR.*0.000770681078+OPR.*LPCPR.*0.0000346999344+OPR.*OPR.*0.0000202874834+T4max.*Thrust.*-0.00000000212251231+T4max.*FPR.*-0.0000692665696+T4max.*LPCPR.*0.000036486005+T4max.*OPR.*-0.00000109566933+T4max.*T4max.*0.0000000544769111+Vratio.*Thrust.*-0.000000980437888+Vratio.*FPR.*-0.0132480486+Vratio.*LPCPR.*-0.0825760778+Vratio.*OPR.*0.00185308179+Vratio.*T4max.*-0.0000103482963+Vratio.*Vratio.*0.570256604+Loading.*Thrust.*0.000000941943684+Loading.*FPR.*-0.0350705609+Loading.*LPCPR.*-0.0595044256+Loading.*OPR.*0.00249845651+Loading.*T4max.*-0.0000518362764+Loading.*Vratio.*-0.00857311658+Loading.*Loading.*-0.0755155667+Payload.*Thrust.*-0.000000000179474291+Payload.*FPR.*-0.00000118332246+Payload.*LPCPR.*-0.000000114138247+Payload.*OPR.*-0.00000000578049718+Payload.*T4max.*0.000000000171659028+Payload.*Vratio.*0.000000279097022+Payload.*Loading.*-0.000000166412116+Payload.*Payload.*-0.0000000000599337645+Range2.*Thrust.*-0.000000000837792856+Range2.*FPR.*0.0000218442552+Range2.*LPCPR.*-0.000000383165627+Range2.*OPR.*-0.000000264719975+Range2.*T4max.*-0.0000000167869449+Range2.*Vratio.*0.0000190871404+Range2.*Loading.*0.000000714906327+Range2.*Payload.*-0.000000000182036483+Range2.*Range2.*-0.000000000321241661)) ;
tofl2=(exp(12.0992993+Thrust.*-0.0000321821844+FPR.*-1.60210814+LPCPR.*0.0145305336+OPR.*-0.00300659881+T4max.*-0.000197319145+Vratio.*-2.24539896+Loading.*0.199774353+Payload.*0.0000280698802+Range2.*0.000161039951+Thrust.*Thrust.*0.000000000609749551+FPR.*Thrust.*-0.00000408599387+FPR.*FPR.*0.529277407+LPCPR.*Thrust.*-0.000000815385963+LPCPR.*FPR.*-0.0176041806+LPCPR.*LPCPR.*0.0190569867+OPR.*Thrust.*0.00000000341647974+OPR.*FPR.*0.000998535131+OPR.*LPCPR.*-0.0000992019834+OPR.*OPR.*0.000023091088+T4max.*Thrust.*-0.00000000250902044+T4max.*FPR.*-0.0000832276923+T4max.*LPCPR.*0.000042820993+T4max.*OPR.*-0.00000131737704+T4max.*T4max.*0.0000000626234494+Vratio.*Thrust.*-0.000000797803953+Vratio.*FPR.*0.0770058479+Vratio.*LPCPR.*-0.093074338+Vratio.*OPR.*0.00198870286+Vratio.*T4max.*-0.0000244410663+Vratio.*Vratio.*0.634595307+Loading.*Thrust.*0.000000568112838+Loading.*FPR.*-0.0150126555+Loading.*LPCPR.*-0.0438417367+Loading.*OPR.*0.00210753657+Loading.*T4max.*-0.0000350397899+Loading.*Vratio.*-0.00041072348+Loading.*Loading.*-0.000700280982+Payload.*Thrust.*-0.000000000177536174+Payload.*FPR.*-0.00000114038114+Payload.*LPCPR.*-0.000000116445949+Payload.*OPR.*-0.00000000651691559+Payload.*T4max.*0.000000000177378264+Payload.*Vratio.*0.000000418273309+Payload.*Loading.*-0.000000183035098+Payload.*Payload.*-0.0000000000595384134+Range2.*Thrust.*-0.000000000817351859+Range2.*FPR.*0.0000221106471+Range2.*LPCPR.*-0.000000429999883+Range2.*OPR.*-0.000000264672221+Range2.*T4max.*-0.0000000168157812+Range2.*Vratio.*0.0000198205822+Range2.*Loading.*0.00000027577409+Range2.*Payload.*-0.000000000181071766+Range2.*Range2.*-0.000000000338946726)) ;
TOFL(isif)=tofl1(isif);
TOFL(~isif)=tofl2(~isif);

TSFC=0.6341971404663+0.1187137545232.*logsig((-23.5720716984273)+0.0000011755672.*Thrust+11.9378363745649.*FPR+0.081718389195.*LPCPR+0.0349165744192.*OPR-0.0014537436834.*T4max+4.9082669396932.*Vratio)-0.1073777546937.*logsig((-19.8149923352826)+0.0000130371749.*Thrust+3.5904317512198.*FPR+0.1658966027007.*LPCPR+0.0179609837415.*OPR+0.0020158368616.*T4max+3.6867523528566.*Vratio)-0.0835620550152.*logsig(3.2652707943322+0.0000058008316.*Thrust+1.3845307960553.*FPR-0.0703052443329.*LPCPR+0.1145846631663.*OPR-0.0029577113581.*T4max+0.8087788802836.*Vratio)+0.0987229271889.*logsig((-175.424074611513)+0.0000001097879.*Thrust+75.7171476460349.*FPR+0.214204499131.*LPCPR+0.2167727530037.*OPR-0.0155783761273.*T4max+50.5202857356151.*Vratio)-0.0122890386173.*logsig(32.1868378991031-0.0000323893191.*Thrust-15.3390505870365.*FPR+0.0566993325196.*LPCPR+0.0812260726005.*OPR+0.0061233279266.*T4max-16.1636707839483.*Vratio);

%Calculate weight of the engine:
Engine_Weight=zeros(nruns,1);
isif=HPTStages==1;
weng1=(56209.3686+Thrust.*0.705283278+FPR.*928.123058+LPCPR.*-2645.06428+OPR.*27.3292448+T4max.*-12.7022957+Vratio.*-40481.6707+Loading.*12482.1507+Thrust.*Thrust.*0.00000144956558+FPR.*Thrust.*-0.212705736+FPR.*FPR.*5856.12642+LPCPR.*Thrust.*-0.0255006309+LPCPR.*FPR.*710.068955+LPCPR.*LPCPR.*160.174299+OPR.*Thrust.*0.000145811004+OPR.*FPR.*-14.5175331+OPR.*LPCPR.*-0.579615977+OPR.*OPR.*-0.0358603162+T4max.*Thrust.*-0.0000658967966+T4max.*FPR.*0.901953037+T4max.*LPCPR.*1.06397203+T4max.*OPR.*-0.000386577222+T4max.*T4max.*0.000846798665+Vratio.*Thrust.*-0.0179246929+Vratio.*FPR.*-12493.9299+Vratio.*LPCPR.*-998.159931+Vratio.*OPR.*-4.51425344+Vratio.*T4max.*3.2546891+Vratio.*Vratio.*14195.516+Loading.*Thrust.*0.0358923872+Loading.*FPR.*-6.00287236+Loading.*LPCPR.*-698.250029+Loading.*OPR.*79.0818154+Loading.*T4max.*-1.24682683+Loading.*Vratio.*-5036.76709+Loading.*Loading.*1184.75077) ;
weng2=(72881.8843+Thrust.*0.708792999+FPR.*-5520.48931+LPCPR.*-1919.27102+OPR.*12.3473732+T4max.*-11.8716053+Vratio.*-55175.1483+Loading.*6108.29111+Thrust.*Thrust.*0.00000166320998+FPR.*Thrust.*-0.1963088+FPR.*FPR.*6747.13717+LPCPR.*Thrust.*-0.0329746206+LPCPR.*FPR.*271.641827+LPCPR.*LPCPR.*285.673036+OPR.*Thrust.*0.000297448237+OPR.*FPR.*-5.00354913+OPR.*LPCPR.*-5.59220178+OPR.*OPR.*0.0708632427+T4max.*Thrust.*-0.0000827825198+T4max.*FPR.*0.193146799+T4max.*LPCPR.*1.32118776+T4max.*OPR.*-0.00882781182+T4max.*T4max.*0.00111396701+Vratio.*Thrust.*-0.00390862874+Vratio.*FPR.*-9139.04385+Vratio.*LPCPR.*-1503.48946+Vratio.*OPR.*5.24147818+Vratio.*T4max.*2.57106101+Vratio.*Vratio.*17491.5028+Loading.*Thrust.*0.0287061794+Loading.*FPR.*205.413251+Loading.*LPCPR.*-907.731484+Loading.*OPR.*72.1981833+Loading.*T4max.*-1.02950197+Loading.*Vratio.*-2103.96368+Loading.*Loading.*1125.86722) ;
Engine_Weight(isif)=weng1(isif);
Engine_Weight(~isif)=weng2(~isif);





